package com.xiaomi.apus.helloworld.client;

import com.google.common.util.concurrent.FutureCallback;
import com.google.common.util.concurrent.Futures;
import com.google.common.util.concurrent.ListenableFuture;
import com.xiaomi.apus.ClientConfig;
import com.xiaomi.apus.SwiftClientManager;
import com.xiaomi.apus.helloworld.server.EchoServer;
import com.xiaomi.apus.registry.servicecenter.ServiceCenterRegistryFactory;

public class Client {

    public static void main(String[] args) throws InterruptedException {
        String request = "Hello Xiaomi!";
        ClientConfig<EchoServer.Iface> syncClientConfig =
                new ClientConfig.ClientConfigBuilder<>(EchoServer.Iface.class)
                        .registryFactory(new ServiceCenterRegistryFactory(EchoServer.Iface.class))
                        .build();
        EchoServer.Iface newSyncClient = new SwiftClientManager<>(syncClientConfig).createClient();
        String response = newSyncClient.echo(request);
        System.out.println(response);

        String asyncRequest = "Hello Xiaomi!(async)";
        ClientConfig<EchoServer.AsyncIface> asyncIfaceClientConfig =
                new ClientConfig.ClientConfigBuilder<>(EchoServer.AsyncIface.class)
                        .registryFactory(new ServiceCenterRegistryFactory(EchoServer.AsyncIface.class))
                        .build();
        EchoServer.AsyncIface newAsyncClinet = new SwiftClientManager<>(asyncIfaceClientConfig).createClient();
        ListenableFuture<String> future = newAsyncClinet.echo(asyncRequest);
        Futures.addCallback(future, new FutureCallback<String>() {
            @Override
            public void onSuccess(String result) {
                System.out.println(result);
            }

            @Override
            public void onFailure(Throwable t) {
                t.printStackTrace();
            }
        });
        Thread.sleep(1000);
    }
}